==> kubernetes-model-admissionregistration-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicyBindingListFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingAdmissionPolicyBindingListFluent<A extends ValidatingAdmissionPolicyBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ValidatingAdmissionPolicyBinding item);
  public A setToItems(Integer index,ValidatingAdmissionPolicyBinding item);
  public A addToItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicyBinding... items);
  public A addAllToItems(Collection<ValidatingAdmissionPolicyBinding> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicyBinding... items);
  public A removeAllFromItems(Collection<ValidatingAdmissionPolicyBinding> items);
  public A removeMatchingFromItems(Predicate<ValidatingAdmissionPolicyBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ValidatingAdmissionPolicyBinding> getItems();
  public List<ValidatingAdmissionPolicyBinding> buildItems();
  public ValidatingAdmissionPolicyBinding buildItem(Integer index);
  public ValidatingAdmissionPolicyBinding buildFirstItem();
  public ValidatingAdmissionPolicyBinding buildLastItem();
  public ValidatingAdmissionPolicyBinding buildMatchingItem(Predicate<ValidatingAdmissionPolicyBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ValidatingAdmissionPolicyBindingBuilder> predicate);
  public A withItems(List<ValidatingAdmissionPolicyBinding> items);
  public A withItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicyBinding... items);
  public Boolean hasItems();
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> addNewItem();
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> addNewItemLike(ValidatingAdmissionPolicyBinding item);
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> setNewItemLike(Integer index,ValidatingAdmissionPolicyBinding item);
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> editItem(Integer index);
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> editFirstItem();
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> editLastItem();
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<ValidatingAdmissionPolicyBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ValidatingAdmissionPolicyBindingFluent<ValidatingAdmissionPolicyBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicyBindingListFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingAdmissionPolicyBindingListFluent<A extends ValidatingAdmissionPolicyBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ValidatingAdmissionPolicyBinding item);
  public A setToItems(int index,ValidatingAdmissionPolicyBinding item);
  public A addToItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicyBinding... items);
  public A addAllToItems(Collection<ValidatingAdmissionPolicyBinding> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicyBinding... items);
  public A removeAllFromItems(Collection<ValidatingAdmissionPolicyBinding> items);
  public A removeMatchingFromItems(Predicate<ValidatingAdmissionPolicyBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ValidatingAdmissionPolicyBinding> getItems();
  public List<ValidatingAdmissionPolicyBinding> buildItems();
  public ValidatingAdmissionPolicyBinding buildItem(int index);
  public ValidatingAdmissionPolicyBinding buildFirstItem();
  public ValidatingAdmissionPolicyBinding buildLastItem();
  public ValidatingAdmissionPolicyBinding buildMatchingItem(Predicate<ValidatingAdmissionPolicyBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ValidatingAdmissionPolicyBindingBuilder> predicate);
  public A withItems(List<ValidatingAdmissionPolicyBinding> items);
  public A withItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicyBinding... items);
  public Boolean hasItems();
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> addNewItem();
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> addNewItemLike(ValidatingAdmissionPolicyBinding item);
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> setNewItemLike(int index,ValidatingAdmissionPolicyBinding item);
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> editItem(int index);
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> editFirstItem();
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> editLastItem();
  public ValidatingAdmissionPolicyBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<ValidatingAdmissionPolicyBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ValidatingAdmissionPolicyBindingFluent<ValidatingAdmissionPolicyBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
